@@ -1,5 +1,6 @@
 class SortableInline:
     sortable_field_name = "position"
+
     class Media:
         js = (
             '/static/admin/js/jquery.sortable.js',
@@ -7,4 +8,7 @@ class SortableInline:
 
         css = {
             'all':('/static/admin/css/admin-inlines.css',)
-        }
\ No newline at end of file
+        }
+
+class CollapsibleInline:
+    start_collapsed = False
\ No newline at end of file
